@@ -1,5 +1,5 @@
 from random import randint as _randint
-from re import findall as _findall
+from re import I as _I, findall as _findall
 from socket import inet_ntoa as _ntoa
 from struct import pack as _pack
 
@@ -9,7 +9,9 @@ from .utils import random_lower_str
 
 
 def random_path(min_len=8, max_len=12):
-    return random_lower_str(min_len, max_len)
+    """Get random path. Mainly used to determine 
+    single page applications (SPA) or honeypots"""
+    return '/%s' % random_lower_str(min_len, max_len)
 
 
 def random_wan_ips(count):
@@ -34,17 +36,16 @@ def random_wan_ips(count):
         yield _ntoa(_pack('>I', intip))
 
 
-def _result_filter(r):
-    return bool(r[0]) if isinstance(r, tuple) else bool(r)
-
-
 def netrandom(check_fn,
               result_fn=print,
-              filter_fn=_result_filter,
+              filter_fn=bool,
               limit=1000000,
               workers=512,
               start_cb=lambda: None,
               stop_cb=lambda: None):
+    """Make netrandom checks with check_fn,
+    filtering results with filter_fn,
+    then process results by result_fn"""
     from threading import Thread, Event, Lock
     import sys
 
@@ -102,17 +103,33 @@ def check_spa(host, port=80, ssl=False, timeout=2):
     return 200 <= code < 300
 
 
-def path_checker(path, port=80, ssl=False, timeout=2, body_re=''):
+def path_checker(path, port=80, ssl=False, timeout=2, inc_re='', exc_re=''):
+    """Create check path function to use with netrandom()"""
     def f(host):
         _path = random_path()
 
+        # check for SPA
         code, _ = _chp(host, port, _path, ssl=ssl, timeout=timeout)
 
-        if not 200 <= code < 300 and code != 999:
-            code, body = _chp(host, port, path, ssl=ssl, timeout=timeout)
-            if body_re and _findall(body_re, body.decode(errors='ignore')):
-                return 200 <= code < 300, body
+        if 200 <= code < 300 or code == 999:
+            return b''
 
-        return False, b''
+        # check target path
+        code, body = _chp(host, port, path, ssl=ssl, timeout=timeout)
+
+        if not 200 <= code < 300:
+            return b''
+
+        if exc_re:
+            text = body.decode(errors='ignore')
+            if _findall(exc_re, text, _I):
+                return b''
+
+        if inc_re:
+            text = body.decode(errors='ignore')
+            if not _findall(inc_re, text, _I):
+                return b''
+
+        return body
 
     return f
